@@ -12,8 +12,8 @@
 
 import gi
 gi.require_version('Gtk', '3.0')
-gi.require_version('WebKit2', '4.0')
-gi.require_version('Soup', '2.4')
+gi.require_version('WebKit2', '4.1')
+gi.require_version('Soup', '3.0')
 gi.require_version('Secret', '1')
 gi.require_version('GtkSpell', '3.0')
 gi.require_version("Handy", "1")
@@ -291,7 +291,7 @@ class Application(Gtk.Application, NightApplication):
 
         # First init sync worker
         from eolie.firefox_sync import SyncWorker
-        if SyncWorker.check_modules():
+        if False and SyncWorker.check_modules():
             self.sync_worker = SyncWorker()
             self.sync_worker.pull_loop()
         else:
